summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmblobsphereedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmblobsphereedit.h')
-rw-r--r--kpovmodeler/pmblobsphereedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmblobsphereedit.h b/kpovmodeler/pmblobsphereedit.h
index 53b65ab2..d4f18058 100644
--- a/kpovmodeler/pmblobsphereedit.h
+++ b/kpovmodeler/pmblobsphereedit.h
@@ -34,12 +34,13 @@ class PMFloatEdit ;
class PMBlobSphereEdit : public PMDetailObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMDetailObjectEdit Base;
public:
/**
* Creates a PMBlobSphereEdit with parent and name
*/
- PMBlobSphereEdit( TQWidget* parent, const char* name = 0 );
+ PMBlobSphereEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -34,12 +34,13 @@ class PMFloatEdit ;
public:
/**
- * Creates a PMBlobSphereEdit with parent and name
+ * Creates a PMBlobSphereEdit with tqparent and name
*/